# Agape

Agape is DRY software.

## Description

See [the github repo](https://github.com/MaverikSoftware/agape) for more information.

## License

Copyright (C) 2017-2020 Jeffrey Hallock, Maverik Software  

The (MIT) license.